summaryrefslogtreecommitdiffstats
path: root/chrome/app/breakpad_linux.cc
diff options
context:
space:
mode:
authorjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-07-09 02:17:52 +0000
committerjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-07-09 02:17:52 +0000
commitd24b76866cf1771f5277d7cc2a2272778cea897a (patch)
treefc0cfa59d61006808978d9158d91213eb6c34103 /chrome/app/breakpad_linux.cc
parent35941fdf7a367e4a20778dfe89ec397b36ce301d (diff)
downloadchromium_src-d24b76866cf1771f5277d7cc2a2272778cea897a.zip
chromium_src-d24b76866cf1771f5277d7cc2a2272778cea897a.tar.gz
chromium_src-d24b76866cf1771f5277d7cc2a2272778cea897a.tar.bz2
Attempt to fix the official Google Chrome build on Linux.
Review URL: http://codereview.chromium.org/155261 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@20227 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/app/breakpad_linux.cc')
-rw-r--r--chrome/app/breakpad_linux.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/chrome/app/breakpad_linux.cc b/chrome/app/breakpad_linux.cc
index 8d8492e..6f73d81 100644
--- a/chrome/app/breakpad_linux.cc
+++ b/chrome/app/breakpad_linux.cc
@@ -467,10 +467,10 @@ void EnableCrashDumping() {
true /* install handlers */);
}
// This is defined in chrome/renderer/renderer_logging_linux.cc, it's the
// static string containing the current active URL. We send this in the crash
// report.
-namespace renderer_logging {
+namespace child_process_logging {
extern std::string active_url;
}
@@ -491,8 +491,8 @@ RendererCrashHandler(const void* crash_context, size_t crash_context_size,
iov[0].iov_len = crash_context_size;
iov[1].iov_base = const_cast<char*>(google_update::linux_guid.data());
iov[1].iov_len = google_update::linux_guid.size();
- iov[2].iov_base = const_cast<char*>(renderer_logging::active_url.data());
- iov[2].iov_len = renderer_logging::active_url.size();
+ iov[2].iov_base = const_cast<char*>(child_process_logging::active_url.data());
+ iov[2].iov_len = child_process_logging::active_url.size();
msg.msg_iov = iov;
msg.msg_iovlen = 3;
@@ -467,10 +467,10 @@ void EnableCrashDumping() {
true /* install handlers */);
}
-// This is defined in chrome/renderer/renderer_logging_linux.cc, it's the
+// This is defined in chrome/common/child_process_logging_linux.cc, it's the
// static string containing the current active URL. We send this in the crash
// report.